==> fannypack-2.2.0.tgz: package/es/Table/styled.js <==
var _templateObject = _taggedTemplateLiteralLoose(['\n  caption-side: ', ';\n\n  & {\n    ', ';\n  }\n'], ['\n  caption-side: ', ';\n\n  & {\n    ', ';\n  }\n']),
    _templateObject2 = _taggedTemplateLiteralLoose(['\n  padding: ', 'rem;\n\n  & {\n    ', ';\n  }\n'], ['\n  padding: ', 'rem;\n\n  & {\n    ', ';\n  }\n']),
    _templateObject3 = _taggedTemplateLiteralLoose(['\n  font-weight: bold;\n\n  & {\n    ', ';\n  }\n\n  & {\n    ', ';\n  }\n'], ['\n  font-weight: bold;\n\n  & {\n    ', ';\n  }\n\n  & {\n    ', ';\n  }\n']),
    _templateObject4 = _taggedTemplateLiteralLoose(['\n        border-top: 2px solid ', ';\n      '], ['\n        border-top: 2px solid ', ';\n      ']),
    _templateObject5 = _taggedTemplateLiteralLoose(['\n  border: unset;\n\n  & {\n    ', ';\n  }\n\n  & {\n    ', ';\n  }\n'], ['\n  border: unset;\n\n  & {\n    ', ';\n  }\n\n  & {\n    ', ';\n  }\n']),
    _templateObject6 = _taggedTemplateLiteralLoose(['\n        border-bottom: 2px solid ', ';\n      '], ['\n        border-bottom: 2px solid ', ';\n      ']),
    _templateObject7 = _taggedTemplateLiteralLoose(['\n  font-weight: bold;\n  padding: ', 'rem;\n\n  & {\n    ', ';\n  }\n'], ['\n  font-weight: bold;\n  padding: ', 'rem;\n\n  & {\n    ', ';\n  }\n']),
    _templateObject8 = _taggedTemplateLiteralLoose(['\n  & {\n    ', ';\n  }\n'], ['\n  & {\n    ', ';\n  }\n']),
    _templateObject9 = _taggedTemplateLiteralLoose(['\n  ', ' /**/\n\n  & {\n    ', ';\n  }\n'], ['\n  ', ' /**/\n\n  & {\n    ', ';\n  }\n']),
    _templateObject10 = _taggedTemplateLiteralLoose(['\n      & ', ' {\n        border-bottom: 1px solid ', ';\n      }\n    '], ['\n      & ', ' {\n        border-bottom: 1px solid ', ';\n      }\n    ']),
    _templateObject11 = _taggedTemplateLiteralLoose(['\n  width: 100%;\n'], ['\n  width: 100%;\n']),
    _templateObject12 = _taggedTemplateLiteralLoose(['\n  & ', ' ', ':hover {\n    background-color: ', ' !important;\n  }\n'], ['\n  & ', ' ', ':hover {\n    background-color: ', ' !important;\n  }\n']),
    _templateObject13 = _taggedTemplateLiteralLoose(['\n  & ', ' ', ':nth-child(even) {\n    background-color: ', ';\n  }\n'], ['\n  & ', ' ', ':nth-child(even) {\n    background-color: ', ';\n  }\n']),
    _templateObject14 = _taggedTemplateLiteralLoose(['\n  border-collapse: collapse;\n  border-spacing: 0;\n  text-align: left;\n\n  & {\n    ', ';\n  }\n  & {\n    ', ';\n  }\n  & {\n    ', ';\n  }\n\n  & {\n    ', ';\n  }\n'], ['\n  border-collapse: collapse;\n  border-spacing: 0;\n  text-align: left;\n\n  & {\n    ', ';\n  }\n  & {\n    ', ';\n  }\n  & {\n    ', ';\n  }\n\n  & {\n    ', ';\n  }\n']);

function _taggedTemplateLiteralLoose(strings, raw) { strings.raw = raw; return strings; }

import styled, { css } from 'reakit/styled';
import { theme } from 'styled-tools';
import Box from 'reakit/Box';
import Table from 'reakit/Table';

export var Caption = styled(Box)(_templateObject, function (props) {
  return props.position;
}, theme('Table.Caption.base'));

export var TableCell = styled(Box)(_templateObject2, theme('Table.spacing'), theme('Table.Cell.base'));

export var TableFoot = styled(Box)(_templateObject3, function (props) {
  return props.hasBorder && css(_templateObject4, theme('Table.borderColor'));
}, theme('Table.Foot.base'));

export var TableHead = styled(Box)(_templateObject5, function (props) {
  return props.hasBorder && css(_templateObject6, theme('Table.borderColor'));
}, theme('Table.Head.base'));

export var TableHeadCell = styled(Box)(_templateObject7, theme('Table.spacing'), theme('Table.HeadCell.base'));

export var TableRow = styled(Box)(_templateObject8, theme('Table.Row.base'));

export var TableBody = styled(Box)(_templateObject9, function (props) {
  return props.hasBorders && css(_templateObject10, TableRow, theme('Table.borderColor'));
}, theme('Table.Body.base'));

var fullWidthAttributes = css(_templateObject11);
var hoverableAttributes = css(_templateObject12, TableBody, TableRow, theme('Table.hover.backgroundColor'));
var stripedAttributes = css(_templateObject13, TableBody, TableRow, theme('Table.striped.backgroundColor'));

export default styled(Box)(_templateObject14, function (props) {
  return props.isFullWidth && fullWidthAttributes;
}, function (props) {
  return props.isHoverable && hoverableAttributes;
}, function (props) {
  return props.isStriped && stripedAttributes;
}, theme('Table.base'));

==> fannypack-2.8.0.tgz: package/es/Table/styled.js <==
var _templateObject = _taggedTemplateLiteralLoose(['\n  caption-side: ', ';\n\n  & {\n    ', ';\n  }\n'], ['\n  caption-side: ', ';\n\n  & {\n    ', ';\n  }\n']),
    _templateObject2 = _taggedTemplateLiteralLoose(['\n  padding: ', 'rem;\n\n  & {\n    ', ';\n  }\n'], ['\n  padding: ', 'rem;\n\n  & {\n    ', ';\n  }\n']),
    _templateObject3 = _taggedTemplateLiteralLoose(['\n  font-weight: bold;\n\n  & {\n    ', ';\n  }\n\n  & {\n    ', ';\n  }\n'], ['\n  font-weight: bold;\n\n  & {\n    ', ';\n  }\n\n  & {\n    ', ';\n  }\n']),
    _templateObject4 = _taggedTemplateLiteralLoose(['\n        border-top: 2px solid ', ';\n      '], ['\n        border-top: 2px solid ', ';\n      ']),
    _templateObject5 = _taggedTemplateLiteralLoose(['\n  border: unset;\n\n  & {\n    ', ';\n  }\n\n  & {\n    ', ';\n  }\n'], ['\n  border: unset;\n\n  & {\n    ', ';\n  }\n\n  & {\n    ', ';\n  }\n']),
    _templateObject6 = _taggedTemplateLiteralLoose(['\n        border-bottom: 2px solid ', ';\n      '], ['\n        border-bottom: 2px solid ', ';\n      ']),
    _templateObject7 = _taggedTemplateLiteralLoose(['\n  font-weight: bold;\n  padding: ', 'rem;\n\n  & {\n    ', ';\n  }\n'], ['\n  font-weight: bold;\n  padding: ', 'rem;\n\n  & {\n    ', ';\n  }\n']),
    _templateObject8 = _taggedTemplateLiteralLoose(['\n  & {\n    ', ';\n  }\n'], ['\n  & {\n    ', ';\n  }\n']),
    _templateObject9 = _taggedTemplateLiteralLoose(['\n  ', ' /**/\n\n  & {\n    ', ';\n  }\n'], ['\n  ', ' /**/\n\n  & {\n    ', ';\n  }\n']),
    _templateObject10 = _taggedTemplateLiteralLoose(['\n      & ', ' {\n        border-bottom: 1px solid ', ';\n      }\n    '], ['\n      & ', ' {\n        border-bottom: 1px solid ', ';\n      }\n    ']),
    _templateObject11 = _taggedTemplateLiteralLoose(['\n  width: 100%;\n'], ['\n  width: 100%;\n']),
    _templateObject12 = _taggedTemplateLiteralLoose(['\n  & ', ' ', ':hover {\n    background-color: ', ' !important;\n  }\n'], ['\n  & ', ' ', ':hover {\n    background-color: ', ' !important;\n  }\n']),
    _templateObject13 = _taggedTemplateLiteralLoose(['\n  & ', ' ', ':nth-child(even) {\n    background-color: ', ';\n  }\n'], ['\n  & ', ' ', ':nth-child(even) {\n    background-color: ', ';\n  }\n']),
    _templateObject14 = _taggedTemplateLiteralLoose(['\n  border-collapse: collapse;\n  border-spacing: 0;\n  text-align: left;\n\n  & {\n    ', ';\n  }\n  & {\n    ', ';\n  }\n  & {\n    ', ';\n  }\n\n  & {\n    ', ';\n  }\n'], ['\n  border-collapse: collapse;\n  border-spacing: 0;\n  text-align: left;\n\n  & {\n    ', ';\n  }\n  & {\n    ', ';\n  }\n  & {\n    ', ';\n  }\n\n  & {\n    ', ';\n  }\n']);

function _taggedTemplateLiteralLoose(strings, raw) { strings.raw = raw; return strings; }

import styled, { css } from 'reakit/styled';
import { theme } from 'styled-tools';
import Box from 'reakit/Box';

export var Caption = styled(Box)(_templateObject, function (props) {
  return props.position;
}, theme('Table.Caption.base'));

export var TableCell = styled(Box)(_templateObject2, theme('Table.spacing'), theme('Table.Cell.base'));

export var TableFoot = styled(Box)(_templateObject3, function (props) {
  return props.hasBorder && css(_templateObject4, theme('Table.borderColor'));
}, theme('Table.Foot.base'));

export var TableHead = styled(Box)(_templateObject5, function (props) {
  return props.hasBorder && css(_templateObject6, theme('Table.borderColor'));
}, theme('Table.Head.base'));

export var TableHeadCell = styled(Box)(_templateObject7, theme('Table.spacing'), theme('Table.HeadCell.base'));

export var TableRow = styled(Box)(_templateObject8, theme('Table.Row.base'));

export var TableBody = styled(Box)(_templateObject9, function (props) {
  return props.hasBorders && css(_templateObject10, TableRow, theme('Table.borderColor'));
}, theme('Table.Body.base'));

var fullWidthProperties = css(_templateObject11);
var hoverableProperties = css(_templateObject12, TableBody, TableRow, theme('Table.hover.backgroundColor'));
var stripedProperties = css(_templateObject13, TableBody, TableRow, theme('Table.striped.backgroundColor'));

export default styled(Box)(_templateObject14, function (props) {
  return props.isFullWidth && fullWidthProperties;
}, function (props) {
  return props.isHoverable && hoverableProperties;
}, function (props) {
  return props.isStriped && stripedProperties;
}, theme('Table.base'));
